# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.21
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.upstream_group_reconcile_response import UpstreamGroupReconcileResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestUpstreamGroupReconcileResponse(unittest.TestCase):
    """UpstreamGroupReconcileResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UpstreamGroupReconcileResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.upstream_group_reconcile_response.UpstreamGroupReconcileResponse()  # noqa: E501
        if include_optional :
            return UpstreamGroupReconcileResponse(
                groups_added_to = [
                    agilicus_api.models.group_reconcile_record.GroupReconcileRecord(
                        name = 'My Timesheet Users', 
                        org_id = 'IAsl3dl40aSsfLKiU76', 
                        group_id = 'IAsl3dl40aSsfLKiU76', )
                    ], 
                groups_removed_from = [
                    agilicus_api.models.group_reconcile_record.GroupReconcileRecord(
                        name = 'My Timesheet Users', 
                        org_id = 'IAsl3dl40aSsfLKiU76', 
                        group_id = 'IAsl3dl40aSsfLKiU76', )
                    ], 
                resulting_groups = [
                    agilicus_api.models.group_reconcile_record.GroupReconcileRecord(
                        name = 'My Timesheet Users', 
                        org_id = 'IAsl3dl40aSsfLKiU76', 
                        group_id = 'IAsl3dl40aSsfLKiU76', )
                    ]
            )
        else :
            return UpstreamGroupReconcileResponse(
        )

    def testUpstreamGroupReconcileResponse(self):
        """Test UpstreamGroupReconcileResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
